# Generated by roxygen2: do not edit by hand

S3method(print,ctSweepM_result)
S3method(print,ctSweepS_result)
S3method(print,dtSweep_result)
S3method(print,otSweep_result)
S3method(print,tsqca_result)
S3method(summary,ctSweepM_result)
S3method(summary,ctSweepS_result)
S3method(summary,dtSweep_result)
S3method(summary,otSweep_result)
S3method(summary,tsqca_result)
export(compute_fiss_core)
export(config_chart_from_paths)
export(config_chart_multi_solutions)
export(ctSweepM)
export(ctSweepS)
export(dtSweep)
export(extract_terms)
export(format_qca_solution)
export(format_qca_solutions)
export(format_qca_term)
export(generate_config_chart)
export(generate_cross_threshold_chart)
export(generate_fiss_chart)
export(generate_report)
export(generate_solution_note)
export(identify_epi)
export(otSweep)
export(print_fiss_summary)
importFrom(QCA,minimize)
importFrom(QCA,truthTable)
importFrom(utils,capture.output)
