#' Sample dataset for ThSQCA examples
#'
#' A small artificial dataset with variables:
#' \describe{
#'   \item{Y}{Outcome (numeric)}
#'   \item{X1}{Condition 1}
#'   \item{X2}{Condition 2}
#'   \item{X3}{Condition 3}
#' }
#'
#' @format A data frame with 80 rows and 4 variables.
"sample_data"
