% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_helpers.R
\name{split_solution_terms}
\alias{split_solution_terms}
\title{Split solution expression into terms}
\usage{
split_solution_terms(solution)
}
\arguments{
\item{solution}{Character. Solution expression (e.g., "X1*X2 + X3").}
}
\value{
Character vector of terms.
}
\description{
Split solution expression into terms
}
\keyword{internal}
