% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{get_config_labels}
\alias{get_config_labels}
\title{Get labels for configuration chart based on language}
\usage{
get_config_labels(language)
}
\description{
Get labels for configuration chart based on language
}
\keyword{internal}
