% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{add_metrics_rows}
\alias{add_metrics_rows}
\title{Add metrics rows to markdown table}
\usage{
add_metrics_rows(table_str, metrics, labels)
}
\description{
Add metrics rows to markdown table
}
\keyword{internal}
