% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_report.R
\name{write_simple_report}
\alias{write_simple_report}
\title{Write simple report content}
\usage{
write_simple_report(
  result,
  con,
  include_chart = TRUE,
  chart_symbol_set = "unicode",
  chart_level = "term",
  solution_note = TRUE,
  solution_note_style = "simple",
  solution_note_lang = "en",
  include_raw_output = TRUE,
  use_fiss = FALSE
)
}
\description{
Write simple report content
}
\keyword{internal}
