% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ThSQCA-package.R
\docType{package}
\name{ThSQCA-package}
\alias{ThSQCA}
\alias{ThSQCA-package}
\title{ThSQCA: Threshold-Sweep QCA}
\description{
Provides threshold sweep methods for Qualitative Comparative Analysis (QCA). Implements Condition Threshold Sweep-Single (CTS-S), Condition Threshold Sweep-Multiple (CTS-M), Outcome Threshold Sweep (OTS), and Dual Threshold Sweep (DTS) for systematic exploration of threshold calibration effects on crisp-set QCA results. These methods extend traditional robustness approaches by treating threshold variation as an exploratory tool for discovering causal structures. Also provides Fiss (2011) \doi{10.5465/amj.2011.60263120} core/peripheral condition classification via compute_fiss_core() and generate_fiss_chart(), enabling four-symbol configuration charts that distinguish core conditions (present in both parsimonious and intermediate solutions) from peripheral conditions (intermediate only). Built on top of the 'QCA' package by Dusa (2019) \doi{10.1007/978-3-319-75668-4}, with function arguments following 'QCA' conventions. Based on set-theoretic methods by Ragin (2008) \doi{10.7208/chicago/9780226702797.001.0001} and established robustness protocols by Oana and Schneider (2024) \doi{10.1177/00491241211036158}. This package supersedes 'TSQCA'; see the NEWS file for migration guidance.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/im-research-yt/ThSQCA}
  \item \doi{10.5281/zenodo.17899390}
  \item Report bugs at \url{https://github.com/im-research-yt/ThSQCA/issues}
}

}
\author{
\strong{Maintainer}: Yuki Toyoda \email{yuki.toyoda.ds@hosei.ac.jp}

Authors:
\itemize{
  \item Yuki Toyoda \email{yuki.toyoda.ds@hosei.ac.jp}
}

Other contributors:
\itemize{
  \item Japan Society for the Promotion of Science (KAKENHI Grant Number JP20K01998) [funder]
}

}
\keyword{internal}
