% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_fiss_core.R
\name{extract_sol_terms}
\alias{extract_sol_terms}
\title{Extract solution terms from a QCA solution object (intermediate or parsim)}
\usage{
extract_sol_terms(sol)
}
\arguments{
\item{sol}{QCA solution object}
}
\value{
Character vector of terms (prime implicants), or character(0)
}
\description{
Extract solution terms from a QCA solution object (intermediate or parsim)
}
\keyword{internal}
