% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_helpers.R
\name{df_to_md_table}
\alias{df_to_md_table}
\title{Convert data frame to Markdown table}
\usage{
df_to_md_table(df, digits = 3)
}
\arguments{
\item{df}{Data frame to convert.}

\item{digits}{Number of decimal places for numeric columns.}
}
\value{
Character string of Markdown table.
}
\description{
Convert data frame to Markdown table
}
\keyword{internal}
