% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sample_data.R
\docType{data}
\name{sample_data}
\alias{sample_data}
\title{Sample dataset for ThSQCA examples}
\format{
A data frame with 80 rows and 4 variables.
}
\usage{
sample_data
}
\description{
A small artificial dataset with variables:
\describe{
  \item{Y}{Outcome (numeric)}
  \item{X1}{Condition 1}
  \item{X2}{Condition 2}
  \item{X3}{Condition 3}
}
}
\keyword{datasets}
