% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{build_single_chart}
\alias{build_single_chart}
\title{Build configuration chart for a single solution}
\usage{
build_single_chart(
  paths,
  sol,
  symbols,
  labels,
  include_metrics,
  condition_order = NULL,
  solution_index = 1
)
}
\description{
Build configuration chart for a single solution
}
\keyword{internal}
