% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{extract_solution_list}
\alias{extract_solution_list}
\title{Extract solution list from QCA object}
\usage{
extract_solution_list(sol)
}
\description{
Extract solution list from QCA object
}
\note{
When dir.exp is specified, the true Intermediate solution is stored in
  sol$i.sol, not sol$solution (which contains the Parsimonious solution).
}
\keyword{internal}
