% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_helpers.R
\name{get_all_terms}
\alias{get_all_terms}
\title{Get all unique terms from multiple solutions}
\usage{
get_all_terms(sol_list)
}
\arguments{
\item{sol_list}{List of solution character vectors from minimize().}
}
\value{
List with:
  \itemize{
    \item \code{all_terms} — all terms (with duplicates)
    \item \code{unique_terms} — unique terms
    \item \code{term_counts} — table of term frequencies
  }
}
\description{
Get all unique terms from multiple solutions
}
\keyword{internal}
