% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{extract_conditions_from_paths}
\alias{extract_conditions_from_paths}
\title{Extract all unique conditions from paths}
\usage{
extract_conditions_from_paths(paths)
}
\arguments{
\item{paths}{Character vector of paths}
}
\value{
Character vector of unique condition names (without ~)
}
\description{
Extract all unique conditions from paths
}
\keyword{internal}
