% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_core.R
\name{get_n_solutions}
\alias{get_n_solutions}
\title{Get the number of intermediate solutions}
\usage{
get_n_solutions(sol)
}
\arguments{
\item{sol}{A solution object returned by \code{QCA::minimize()}.}
}
\value{
Integer. Number of intermediate solutions, or 0 if none.
}
\description{
Get the number of intermediate solutions
}
\note{
When dir.exp is specified, the true Intermediate solution is stored in
  sol$i.sol, not sol$solution (which contains the Parsimonious solution).
  See \code{\link{collect_unique_i_sol}} for why deduplication is required
  when multiple prime implicant charts are present.
}
\keyword{internal}
