% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_fiss_core.R
\name{extract_cond_status_map}
\alias{extract_cond_status_map}
\title{Extract all (condition, status) pairs present in a set of solution terms}
\usage{
extract_cond_status_map(terms, conditions)
}
\arguments{
\item{terms}{Character vector of solution terms (e.g. c("X1*X2", "~X3"))}

\item{conditions}{Character vector of all condition names}
}
\value{
Named list: condition name -> character vector of statuses
  ("present" and/or "absent") found in any term
}
\description{
Extract all (condition, status) pairs present in a set of solution terms
}
\keyword{internal}
