% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_helpers.R
\name{escape_md}
\alias{escape_md}
\title{Escape special characters for Markdown}
\usage{
escape_md(text)
}
\arguments{
\item{text}{Character. Text to escape.}
}
\value{
Character. Text with special characters escaped.
}
\description{
Escapes asterisks and other special characters that have special
meaning in Markdown syntax.
}
\keyword{internal}
