% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{extract_path_metrics_for_chart}
\alias{extract_path_metrics_for_chart}
\title{Extract per-path metrics for configuration chart}
\usage{
extract_path_metrics_for_chart(sol, solution_index = 1)
}
\description{
Extract per-path metrics for configuration chart
}
\keyword{internal}
