% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_fiss_core.R
\name{SYMBOL_SETS_FISS}
\alias{SYMBOL_SETS_FISS}
\title{Fiss-style symbol sets (4 symbols)}
\usage{
SYMBOL_SETS_FISS
}
\description{
Fiss-style symbol sets (4 symbols)
}
\keyword{internal}
