% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{extract_solution_metrics_for_chart}
\alias{extract_solution_metrics_for_chart}
\title{Extract solution-level metrics for configuration chart}
\usage{
extract_solution_metrics_for_chart(sol, solution_index = 1)
}
\description{
Extract solution-level metrics for configuration chart
}
\keyword{internal}
