% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{extract_paths_from_solution}
\alias{extract_paths_from_solution}
\title{Extract paths from a single solution}
\usage{
extract_paths_from_solution(solution)
}
\description{
Extract paths from a single solution
}
\keyword{internal}
