% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_config_chart.R
\name{SYMBOL_SETS}
\alias{SYMBOL_SETS}
\title{Symbol sets for configuration charts}
\usage{
SYMBOL_SETS
}
\description{
Symbol sets for configuration charts
}
\keyword{internal}
