% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsqca_report.R
\name{write_full_report}
\alias{write_full_report}
\title{Write full report content}
\usage{
write_full_report(
  result,
  con,
  dat = NULL,
  desc_vars = NULL,
  include_chart = TRUE,
  chart_symbol_set = "unicode",
  chart_level = "term",
  solution_note = TRUE,
  solution_note_style = "simple",
  solution_note_lang = "en",
  include_raw_output = TRUE,
  use_fiss = FALSE
)
}
\description{
Write full report content
}
\keyword{internal}
